@@ -168,7 +168,7 @@ class APIVisitor(APIParserVisitor):
             self.isFinished = False
 
         # 需要输出的文件名
-        param = ctx.ECHO_OPEN().getText().partition(' ')[2]
+        param = ctx.ECHO().getText().partition(' ')[2]
         if param is not None:
             param = param.splitlines()[0]
             parsedObject.update({'param': str(param).strip()})
@@ -220,10 +220,6 @@ class APIVisitor(APIParserVisitor):
         for expression in ctx.SET_EXPRESSION():
             expression_list.append(str(expression.getText()))
 
-        if ctx.SET_AT():
-            parsedObject.update({'scope': "global"})
-        else:
-            parsedObject.update({'scope': "local"})
         if len(expression_list) >= 1:
             parsedObject.update({'optionName': expression_list[0]})
         if len(expression_list) >= 2:
@@ -348,11 +344,11 @@ class APIVisitor(APIParserVisitor):
                         newLines.append(line[4:])
                     block = "\n".join(newLines)
                 parsedObject.update({'block': block})
-
             else:
                 self.isFinished = False
         else:
             self.isFinished = False
+
         # 获取错误代码
         errorCode = 0
         errorMsg = None
@@ -378,7 +374,12 @@ class APIVisitor(APIParserVisitor):
             parsedObject.update({'expression': ""})
 
         if ctx.ASSERT_NAME() is not None:
-            parsedObject.update({'assertName': str(ctx.ASSERT_NAME().getText()).strip()})
+            assertName = str(ctx.ASSERT_NAME().getText()).strip()
+            if assertName.startswith('"') and assertName.endswith('"'):
+                assertName = assertName[1:-1]
+            if assertName.startswith("'") and assertName.endswith("'"):
+                assertName = assertName[1:-1]
+            parsedObject.update({'assertName': assertName})
         else:
             parsedObject.update({'assertName': None})
 
@@ -604,6 +605,8 @@ class APIVisitor(APIParserVisitor):
             commond = str(" ".join(commands)).strip()
             if commond.startswith('"') and commond.endswith('"'):
                 commond = commond[1:-1]
+            if commond.startswith("'") and commond.endswith("'"):
+                commond = commond[1:-1]
             parsedObject.update({"command": commond})
         if ctx.SSH_CONNECT() is not None:
             parsedObject.update({"action": "connect"})
@@ -678,6 +681,71 @@ class APIVisitor(APIParserVisitor):
         self.errorCode = errorCode
         self.errorMsg = errorMsg
 
+    def visitData(self, ctx: APIParser.DataContext):
+        parsedObject = {'name': 'DATA'}
+
+        if ctx.DATA_SET() is not None:
+            parsedObject.update({"action": "set"})
+            if ctx.DATA_SEEDFILE() is not None:
+                parsedObject.update({"option": "seedDir"})
+                if len(ctx.DATA_EXPRESSION()) != 0:
+                    seedDir = str(ctx.DATA_EXPRESSION()[0].getText()).strip()
+                    if seedDir.startswith('"') and seedDir.endswith('"'):
+                        seedDir = seedDir[1:-1]
+                    elif seedDir.startswith("'") and seedDir.endswith("'"):
+                        seedDir = seedDir[1:-1]
+                    parsedObject.update({"seedDir": seedDir})
+
+        if ctx.DATA_CONVERT() is not None:
+            parsedObject.update({"action": "convert"})
+            parsedObject.update({"sourceFileType": str(ctx.DATA_FILETYPE()[0].getText())})
+            parsedObject.update({"targetFileType": str(ctx.DATA_FILETYPE()[1].getText())})
+            sourceFile = str(ctx.DATA_EXPRESSION()[0].getText())
+            targetFile = str(ctx.DATA_EXPRESSION()[1].getText())
+            if sourceFile.startswith('"') and sourceFile.endswith('"'):
+                sourceFile = sourceFile[1:-1]
+            elif sourceFile.startswith("'") and sourceFile.endswith("'"):
+                sourceFile = sourceFile[1:-1]
+            if targetFile.startswith('"') and targetFile.endswith('"'):
+                targetFile = targetFile[1:-1]
+            elif targetFile.startswith("'") and targetFile.endswith("'"):
+                targetFile = targetFile[1:-1]
+            parsedObject.update({"sourceFile": sourceFile})
+            parsedObject.update({"targetFile": targetFile})
+
+        if ctx.DATA_CREATE() is not None:
+            parsedObject.update({"action": "create"})
+            parsedObject.update({"fileType": str(ctx.DATA_FILETYPE()[0].getText())})
+            targetFile = str(ctx.DATA_EXPRESSION()[0].getText())
+            if targetFile.startswith('"') and targetFile.endswith('"'):
+                targetFile = targetFile[1:-1]
+            elif targetFile.startswith("'") and targetFile.endswith("'"):
+                targetFile = targetFile[1:-1]
+            parsedObject.update({"targetFile": targetFile})
+            if ctx.DATA_ROWS() is not None:
+                parsedObject.update({"rowCount": int(ctx.DATA_INT().getText())})
+            else:
+                # 默认输出是1行
+                parsedObject.update({"rowCount": 1})
+            columnExpression = ""
+            if ctx.DATACOLUMN_CONTENT() is not None:
+                columnExpression = str(ctx.DATACOLUMN_CONTENT().getText()).strip()
+                if columnExpression.endswith(')'):
+                    columnExpression = columnExpression[:-1]
+            parsedObject.update({"columnExpression": str(columnExpression)})
+
+        # 处理错误信息
+        errorCode = 0
+        errorMsg = None
+        if ctx.exception is not None:
+            errorCode = 1
+            errorMsg = ctx.exception.message
+            self.isFinished = False
+
+        self.parsedObject = parsedObject
+        self.errorCode = errorCode
+        self.errorMsg = errorMsg
+
     def visitCompare(self, ctx: APIParser.CompareContext):
         parsedObject = {'name': 'COMPARE'}
 
