@@ -59,10 +59,9 @@ def rewiteStatement(cls, statement: str, commandScriptFile: str):
             varName = str(match_obj.group(1)).strip()
 
             # 先尝试在MAPPING文件中进行查找替换
-            if cls.testOptions.get("TESTREWRITE").upper() == 'ON':
-                mappingResult = cls.cmdMappingHandler.RewriteWord(commandScriptFile, varName)
-                if varName != mappingResult:
-                    statement = statement.replace(searchResult, str(mappingResult))
+            mappingResult = cls.cmdMappingHandler.RewriteWord(commandScriptFile, varName)
+            if varName != mappingResult:
+                statement = statement.replace(searchResult, str(mappingResult))
 
             # 尝试本地变量
             try:
@@ -223,7 +222,7 @@ def parseSQLHints(commandHints: list):
             r"^LogFilter(\s+)(.*)", commandHint, re.IGNORECASE | re.DOTALL)
         if match_obj:
             # 可能有多个Filter信息
-            sqlFilter = match_obj.group(5).strip()
+            sqlFilter = match_obj.group(2).strip()
             if "LogFilter" in commandHintList:
                 commandHintList["LogFilter"].append(sqlFilter)
             else:
@@ -234,7 +233,7 @@ def parseSQLHints(commandHints: list):
         match_obj = re.search(
             r"^LogMask(\s+)(.*)", commandHint, re.IGNORECASE | re.DOTALL)
         if match_obj:
-            sqlMask = match_obj.group(5).strip()
+            sqlMask = match_obj.group(2).strip()
             if "LogMask" in commandHintList:
                 commandHintList["LogMask"].append(sqlMask)
             else:
